@@ -122,7 +122,7 @@ def tensorleap_load_model(prediction_types: Optional[List[PredictionTypeHandler]
                 # keras interface
                 def __call__(self, arg):
                     ret = self.model(arg)
-                    if isinstance(ret, list or tuple):
+                    if isinstance(ret, list):
                         return [r.numpy() for r in ret]
 
                     return ret.numpy()
